package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ss.userCard.domain.UserCard;
import com.ruoyi.ss.userCard.domain.UserCardVO;
import com.ruoyi.ss.userCard.domain.UserCardQuery;
import com.ruoyi.ss.userCard.service.IUserCardService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户卡券Controller
 *
 * @author qzz
 * @date 2025-03-19
 */
@RestController
@RequestMapping("/system/getRecords")
public class UserCardController extends BaseController
{
    @Autowired
    private IUserCardService userCardService;

    /**
     * 查询用户卡券列表
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:list')")
    @GetMapping("/list")
    public TableDataInfo list(UserCardQuery query)
    {
        startPage();
        startOrderBy();
        List<UserCardVO> list = userCardService.selectUserCardList(query);
        return getDataTable(list);
    }

    /**
     * 导出用户卡券列表
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:export')")
    @Log(title = "用户卡券", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UserCardQuery query)
    {
        List<UserCardVO> list = userCardService.selectUserCardList(query);
        ExcelUtil<UserCardVO> util = new ExcelUtil<UserCardVO>(UserCardVO.class);
        util.exportExcel(response, list, "用户卡券数据");
    }

    /**
     * 获取用户卡券详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:query')")
    @GetMapping(value = "/{recordId}")
    public AjaxResult getInfo(@PathVariable("recordId") Long recordId)
    {
        return success(userCardService.selectUserCardById(recordId));
    }

    /**
     * 新增用户卡券
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:add')")
    @Log(title = "用户卡券", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UserCard userCard)
    {
        return toAjax(userCardService.insertUserCard(userCard));
    }

    /**
     * 修改用户卡券
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:edit')")
    @Log(title = "用户卡券", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UserCard userCard)
    {
        return toAjax(userCardService.updateUserCard(userCard));
    }

    /**
     * 删除用户卡券
     */
    @PreAuthorize("@ss.hasPermi('system:getRecords:remove')")
    @Log(title = "用户卡券", businessType = BusinessType.DELETE)
	@DeleteMapping("/{recordIds}")
    public AjaxResult remove(@PathVariable Long[] recordIds)
    {
        return toAjax(userCardService.deleteUserCardByRecordIds(recordIds));
    }
}
